from typing import Final

LONG_PASSWORD: Final[int]
FOUND_ROWS: Final[int]
LONG_FLAG: Final[int]
CONNECT_WITH_DB: Final[int]
NO_SCHEMA: Final[int]
COMPRESS: Final[int]
ODBC: Final[int]
LOCAL_FILES: Final[int]
IGNORE_SPACE: Final[int]
PROTOCOL_41: Final[int]
INTERACTIVE: Final[int]
SSL: Final[int]
IGNORE_SIGPIPE: Final[int]
TRANSACTIONS: Final[int]
SECURE_CONNECTION: Final[int]
MULTI_STATEMENTS: Final[int]
MULTI_RESULTS: Final[int]
PS_MULTI_RESULTS: Final[int]
PLUGIN_AUTH: Final[int]
CONNECT_ATTRS: Final[int]
PLUGIN_AUTH_LENENC_CLIENT_DATA: Final[int]
CAPABILITIES: Final[int]
HANDLE_EXPIRED_PASSWORDS: Final[int]
SESSION_TRACK: Final[int]
DEPRECATE_EOF: Final[int]
