from typing import Final

CR_ERROR_FIRST: Final = 2000
CR_UNKNOWN_ERROR: Final = 2000
CR_SOCKET_CREATE_ERROR: Final = 2001
CR_CONNECTION_ERROR: Final = 2002
CR_CONN_HOST_ERROR: Final = 2003
CR_IPSOCK_ERROR: Final = 2004
CR_UNKNOWN_HOST: Final = 2005
CR_SERVER_GONE_ERROR: Final = 2006
CR_VERSION_ERROR: Final = 2007
CR_OUT_OF_MEMORY: Final = 2008
CR_WRONG_HOST_INFO: Final = 2009
CR_LOCALHOST_CONNECTION: Final = 2010
CR_TCP_CONNECTION: Final = 2011
CR_SERVER_HANDSHAKE_ERR: Final = 2012
CR_SERVER_LOST: Final = 2013
CR_COMMANDS_OUT_OF_SYNC: Final = 2014
CR_NAMEDPIPE_CONNECTION: Final = 2015
CR_NAMEDPIPEWAIT_ERROR: Final = 2016
CR_NAMEDPIPEOPEN_ERROR: Final = 2017
CR_NAMEDPIPESETSTATE_ERROR: Final = 2018
CR_CANT_READ_CHARSET: Final = 2019
CR_NET_PACKET_TOO_LARGE: Final = 2020
CR_EMBEDDED_CONNECTION: Final = 2021
CR_PROBE_SLAVE_STATUS: Final = 2022
CR_PROBE_SLAVE_HOSTS: Final = 2023
CR_PROBE_SLAVE_CONNECT: Final = 2024
CR_PROBE_MASTER_CONNECT: Final = 2025
CR_SSL_CONNECTION_ERROR: Final = 2026
CR_MALFORMED_PACKET: Final = 2027
CR_WRONG_LICENSE: Final = 2028
CR_NULL_POINTER: Final = 2029
CR_NO_PREPARE_STMT: Final = 2030
CR_PARAMS_NOT_BOUND: Final = 2031
CR_DATA_TRUNCATED: Final = 2032
CR_NO_PARAMETERS_EXISTS: Final = 2033
CR_INVALID_PARAMETER_NO: Final = 2034
CR_INVALID_BUFFER_USE: Final = 2035
CR_UNSUPPORTED_PARAM_TYPE: Final = 2036
CR_SHARED_MEMORY_CONNECTION: Final = 2037
CR_SHARED_MEMORY_CONNECT_REQUEST_ERROR: Final = 2038
CR_SHARED_MEMORY_CONNECT_ANSWER_ERROR: Final = 2039
CR_SHARED_MEMORY_CONNECT_FILE_MAP_ERROR: Final = 2040
CR_SHARED_MEMORY_CONNECT_MAP_ERROR: Final = 2041
CR_SHARED_MEMORY_FILE_MAP_ERROR: Final = 2042
CR_SHARED_MEMORY_MAP_ERROR: Final = 2043
CR_SHARED_MEMORY_EVENT_ERROR: Final = 2044
CR_SHARED_MEMORY_CONNECT_ABANDONED_ERROR: Final = 2045
CR_SHARED_MEMORY_CONNECT_SET_ERROR: Final = 2046
CR_CONN_UNKNOW_PROTOCOL: Final = 2047
CR_INVALID_CONN_HANDLE: Final = 2048
CR_SECURE_AUTH: Final = 2049
CR_FETCH_CANCELED: Final = 2050
CR_NO_DATA: Final = 2051
CR_NO_STMT_METADATA: Final = 2052
CR_NO_RESULT_SET: Final = 2053
CR_NOT_IMPLEMENTED: Final = 2054
CR_SERVER_LOST_EXTENDED: Final = 2055
CR_STMT_CLOSED: Final = 2056
CR_NEW_STMT_METADATA: Final = 2057
CR_ALREADY_CONNECTED: Final = 2058
CR_AUTH_PLUGIN_CANNOT_LOAD: Final = 2059
CR_DUPLICATE_CONNECTION_ATTR: Final = 2060
CR_AUTH_PLUGIN_ERR: Final = 2061
CR_INSECURE_API_ERR: Final = 2062
CR_FILE_NAME_TOO_LONG: Final = 2063
CR_SSL_FIPS_MODE_ERR: Final = 2064
CR_DEPRECATED_COMPRESSION_NOT_SUPPORTED: Final = 2065
CR_COMPRESSION_WRONGLY_CONFIGURED: Final = 2066
CR_KERBEROS_USER_NOT_FOUND: Final = 2067
CR_LOAD_DATA_LOCAL_INFILE_REJECTED: Final = 2068
CR_LOAD_DATA_LOCAL_INFILE_REALPATH_FAIL: Final = 2069
CR_DNS_SRV_LOOKUP_FAILED: Final = 2070
CR_MANDATORY_TRACKER_NOT_FOUND: Final = 2071
CR_INVALID_FACTOR_NO: Final = 2072
CR_ERROR_LAST: Final = 2072
