from typing import Final

COM_SLEEP: Final[int]
COM_QUIT: Final[int]
COM_INIT_DB: Final[int]
COM_QUERY: Final[int]
COM_FIELD_LIST: Final[int]
COM_CREATE_DB: Final[int]
COM_DROP_DB: Final[int]
COM_REFRESH: Final[int]
COM_SHUTDOWN: Final[int]
COM_STATISTICS: Final[int]
COM_PROCESS_INFO: Final[int]
COM_CONNECT: Final[int]
COM_PROCESS_KILL: Final[int]
COM_DEBUG: Final[int]
COM_PING: Final[int]
COM_TIME: Final[int]
COM_DELAYED_INSERT: Final[int]
COM_CHANGE_USER: Final[int]
COM_BINLOG_DUMP: Final[int]
COM_TABLE_DUMP: Final[int]
COM_CONNECT_OUT: Final[int]
COM_REGISTER_SLAVE: Final[int]
COM_STMT_PREPARE: Final[int]
COM_STMT_EXECUTE: Final[int]
COM_STMT_SEND_LONG_DATA: Final[int]
COM_STMT_CLOSE: Final[int]
COM_STMT_RESET: Final[int]
COM_SET_OPTION: Final[int]
COM_STMT_FETCH: Final[int]
COM_DAEMON: Final[int]
COM_BINLOG_DUMP_GTID: Final[int]
COM_END: Final[int]
