from typing import Final

NOT_NULL: Final = 1
PRI_KEY: Final = 2
UNIQUE_KEY: Final = 4
MULTIPLE_KEY: Final = 8
BLOB: Final = 16
UNSIGNED: Final = 32
ZEROFILL: Final = 64
BINARY: Final = 128
ENUM: Final = 256
AUTO_INCREMENT: Final = 512
TIMESTAMP: Final = 1024
SET: Final = 2048
PART_KEY: Final = 16384
GROUP: Final = 32767
UNIQUE: Final = 65536
